@@ -14,7 +14,6 @@ from .utils import *
 
 DEBUG_MODE = False
 
-
 # Keep track of running server PIDs in a global list. This way,
 # we can ensure they're killed on exit.
 RUNNING_SERVER_PROCESSES = []
@@ -37,8 +36,8 @@ class LanguageTool:
     def __init__(self, language=None, motherTongue=None, remote_server=None):
         if remote_server is not None:
             self._remote = True
-            if remote_server[-1] == '/': remote_server = remote_server[:-1]
-            self._url = '{}/v2/'.format(remote_server)
+            self._url = parse_url(remote_server)
+            self._url = urllib.parse.urljoin(self._url, 'v2/')
             self._update_remote_server_config(self._url)
         elif not self._server_is_alive():
             self._start_server_on_free_port()
@@ -47,6 +46,9 @@ class LanguageTool:
                 language = get_locale_language()
             except ValueError:
                 language = FAILSAFE_LANGUAGE
+        # if self._url[-1] != '/':
+            # self._url += '/'
+        print('self._url:', self._url)
         self._language = LanguageTag(language, self._get_languages())
         self.motherTongue = motherTongue
         self.disabled_rules = set()
@@ -91,17 +93,15 @@ class LanguageTool:
         return {'HUNSPELL_RULE', 'HUNSPELL_NO_SUGGEST_RULE',
                 'MORFOLOGIK_RULE_' + str(self.language).replace('-', '_').upper()}
 
-    def check(self, text: str, srctext=None) -> [Match]:
+    def check(self, text: str) -> [Match]:
         """Match text against enabled rules."""
         url = urllib.parse.urljoin(self._url, 'check')
-        response = self._get_root(url, self._encode(text, srctext))
+        response = self._get_root(url, self._encode(text))
         matches = response['matches']
         return [Match(match) for match in matches]
 
-    def _encode(self, text, srctext=None):
+    def _encode(self, text):
         params = {'language': self.language, 'text': text.encode('utf-8')}
-        if srctext is not None:
-            params['srctext'] = srctext.encode('utf-8')
         if self.motherTongue is not None:
             params['motherTongue'] = self.motherTongue
         if self.disabled_rules:
@@ -116,9 +116,9 @@ class LanguageTool:
             params['enabledCategories'] = ','.join(self.enabled_categories)
         return urllib.parse.urlencode(params).encode()
 
-    def correct(self, text: str, srctext=None) -> str:
+    def correct(self, text: str) -> str:
         """Automatically apply suggestions to the text."""
-        return correct(text, self.check(text, srctext))
+        return correct(text, self.check(text))
     
     def enable_spellchecking(self):
         """Enable spell-checking rules."""
